__version__ = '1.0.9'

from ._apis import (
    ai, 
    detect, 
    event, 
    interactive, 
    media, 
    object, 
    sensor
)

from ._utils.logger_setup import (
    enable_logger, 
    disable_logger, 
    setup_logger
)

def __initialize():
    try:
        import threading
        from ._core.websocket.websocket_client import ws_connect, get_ws_client, init_callback

        logger = setup_logger()
        threading.Thread(target=ws_connect, args=()).start()
        while True:
            ws_client = get_ws_client()
            if ws_client and ws_client.session_id:
                break
        init_callback()
    except Exception as e:
        logger.error(f'An error occurred: {e}')

__initialize()




from crealand._core.bridge.interface import call_api, call_api_async
from crealand._apis import subscribe_event

class event:

    @staticmethod
    def onBroadcastEvent(info,cb):
        subscribe_event.onBroadcastEvent(info,cb)
    
    @staticmethod
    def send_broadcast(info):
        subscribe_event.send_broadcast(info)

    @staticmethod
    def onAreaObjectEvent(runtime_id,action,area_id,cb):
        def cb_wrapper(err,data):
            cb()
        subscribe_event.onAreaObjectEvent(runtime_id,action,area_id,cb)
